@@ -1,5 +1,5 @@
-/*
- * Copyright (C) 2012-2017  B.A.T.M.A.N. contributors:
+/* SPDX-License-Identifier: GPL-2.0 */
+/* Copyright (C) 2012-2018  B.A.T.M.A.N. contributors:
  *
  * Simon Wunderlich
  *
@@ -17,10 +17,11 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  * 02110-1301, USA
  *
+ * License-Filename: LICENSES/preferred/GPL-2.0
  */
 
 #ifndef SOURCE_VERSION
-#define SOURCE_VERSION			"2017.2"
+#define SOURCE_VERSION			"2018.2"
 #endif
 
 #include <net/ethernet.h>
@@ -31,6 +32,7 @@
 #include <time.h>
 #include <sys/select.h>
 #include <sys/types.h>
+#include "bitops.h"
 #include "list.h"
 #include "packet.h"
 
@@ -134,8 +136,7 @@ struct globals {
 	const char *unix_path;
 
 	const char *update_command;
-	struct list_head changed_data_types;
-	uint16_t changed_data_type_count; /* maximum is 256 */
+	DECLARE_BITMAP(changed_data_types, ALFRED_NUM_TYPES);
 
 	struct timespec if_check;
 	struct timespec sync_period;
@@ -147,6 +148,8 @@ struct globals {
 #define debugMalloc(size, num)	malloc(size)
 #define debugFree(ptr, num)	free(ptr)
 
+#define BUILD_BUG_ON(e) ((void)sizeof(char[1 - 2 * !!(e)]))
+
 #define MAX_PAYLOAD ((1 << 16) - 1 - sizeof(struct udphdr))
 
 extern alfred_addr alfred_mcast;
