@@ -1,5 +1,5 @@
-/*
- * Copyright (C) 2009 Clark Williams <williams@redhat.com>
+// SPDX-License-Identifier: GPL-2.0
+/* Copyright (C) 2009 Clark Williams <williams@redhat.com>
  * Copyright (C) 2009 Xiao Guangrong <xiaoguangrong@cn.fujitsu.com>
  *
  * This program is free software; you can redistribute it and/or
@@ -16,6 +16,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  * 02110-1301, USA
  *
+ * License-Filename: LICENSES/preferred/GPL-2.0
  */
 
 #include "debugfs.h"
@@ -46,19 +47,12 @@ static const char *debugfs_known_mountpoints[] = {
 int debugfs_make_path(const char *fmt, const char *mesh_iface, char *buffer,
 		      int size)
 {
-	int len;
-
 	if (strlen(debugfs_mountpoint) == 0) {
 		buffer[0] = '\0';
 		return -1;
 	}
 
-	len = strlen(debugfs_mountpoint) + strlen(fmt) + 1;
-	if (len >= size)
-		return len+1;
-
-	snprintf(buffer, size-1, fmt, debugfs_mountpoint, mesh_iface);
-	return 0;
+	return snprintf(buffer, size, fmt, debugfs_mountpoint, mesh_iface);
 }
 
 static int debugfs_found;
